SocketBloc class

Available extensions

Constructors

SocketBloc({required ApiRest apiRest, bool debugMode = false, required ShpDynamicCrud shpDynamicCrud, required Uuid uuid, required FlutterSocketProvider socketDataProvider, required UtilsDataApiRest utilsDataApiRest, required String endpointSocket})

Properties

apiRest → ApiRest
final
debugMode bool
final
duracionTemporizador Duration
final
endpointSocket String
final
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shpDynamicCrud ShpDynamicCrud
final
socketDataProvider → FlutterSocketProvider
final
state SocketState
The current state.
no setterinherited
stream Stream<SocketState>
The current stream of states.
no setterinherited
timerColecciones Map<String, Timer>
final
utilsDataApiRest → UtilsDataApiRest
final
uuid → Uuid
final

Methods

actualizaNotificacion(Map<String, dynamic> payload) Future<List<Map<String, dynamic>>>

Available on SocketBloc, provided by the SocketFunc extension

add(SocketEvent event) → void
Notifies the Bloc of a new event which triggers all corresponding EventHandler instances.
inherited
addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the event and state Streams. This method should be called when a Bloc is no longer needed. Once close is called, events that are added will not be processed. In addition, if close is called while events are still being processed, the Bloc will finish processing the pending events.
inherited
determinaMensajesSinLeer(List<Map<String, dynamic>> lstData) int

Available on SocketBloc, provided by the SocketFunc extension

emit(SocketState state) → void
emit is only for internal use and should never be called directly outside of tests. The Emitter instance provided to each EventHandler should be used instead.
inherited
finalizaEscuchaSocketDataProvider(String idColeccion) → void
iniciaEscuchaSocketDataProvider(String coleccion) → void
iniciaEscuchaSocketOpcionales({required String endpointSocket, required String idChannel}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on<E extends Event>(EventHandler<E, SocketState> handler, {EventTransformer<E>? transformer}) → void
Register event handler for an event of type E. There should only ever be one event handler per event type E.
inherited
onChange(Change<SocketState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onDone(SocketEvent event, [Object? error, StackTrace? stackTrace]) → void
Called whenever an event handler for a specific Bloc has completed. This may include an error and stackTrace if an uncaught exception occurred within the event handler.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onEvent(SocketEvent event) → void
Called whenever an event is added to the Bloc. A great spot to add logging/analytics at the individual Bloc level.
inherited
onTransition(Transition<SocketEvent, SocketState> transition) → void
Called whenever a transition occurs with the given transition. A transition occurs when a new event is added and a new state is emitted from a corresponding EventHandler.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited