SocketState class

Constructors

SocketState({bool isWorking = false, String error = '', String accion = '', String parametroUi = '', bool inicializo = false, SocketServerStatusAuth serverStatus = SocketServerStatusAuth.connecting, String coleccionActualizada = '', String socketChannelMensajeRecebido = '', List<Map<String, dynamic>> lstMensajes = const [], int mensajesSinLeer = 0})
const

Properties

accion String
final
coleccionActualizada String
final
error String
final
hashCode int
The hash code for this object.
no setterinherited
inicializo bool
final
isWorking bool
final
lstMensajes List<Map<String, dynamic>>
Lista de mensajes recibidos por el socket. Solo se almacena los que tengan un key notifica='true'. Los mensajes posee la siguiente estructura: { 'id': 'id del mensaje', 'coleccion': 'nombre de la colección', 'notifica': true, 'msj': 'mensaje recibido', 'fecha': 'fecha de recepción' }
final
mensajesSinLeer int
final
parametroUi String
final
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverStatus → SocketServerStatusAuth
Este es el estado del socket utulizado en el Login
final
socketChannelMensajeRecebido String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({bool? isWorking, String? error, String? accion, String? parametroUi, bool? inicializo, List<Map<String, dynamic>>? lstMensajes, String? coleccionActualizada, String? socketChannelMensajeRecebido, SocketServerStatusAuth? serverStatus, int? mensajesSinLeer}) SocketState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited