$AuthUtils class

Constructors

$AuthUtils.wrap(AuthUtils $value)

Properties

$reified → dynamic
Retorna la instancia reificada de la clase original.
no setter
$value AuthUtils
The backing Dart value of this $Value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) → $Value?
Obtiene una propiedad o método de la clase puente por su identificador.
$getRuntimeType(Runtime runtime) int
Obtiene el tipo de tiempo de ejecución de la clase puente.
$setProperty(Runtime runtime, String identifier, $Value value) → void
Establece una propiedad de la clase puente por su identificador.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

$declaration → BridgeClassDef
Definición de la clase puente, incluyendo constructores y métodos expuestos.
final
$type → BridgeTypeRef
Referencia al tipo de la clase puente, utilizada por dart_eval para identificarla.
final

Static Methods

$new(Runtime runtime, $Value? target, List<$Value?> args) → $Value?

Constants

clase → const String
Nombre de la clase original que se está exponiendo.
package → const String
Especifica el paquete donde se encuentra definida la clase original.