$EsquemaUtils class

Clase puente que permite la interoperabilidad entre el código interpretado por dart_eval y la clase EsquemaUtils definida en Dart.

Constructors

$EsquemaUtils.wrap(EsquemaUtils $value)
Constructor que envuelve una instancia de EsquemaUtils.

Properties

$reified → dynamic
Devuelve la instancia original de EsquemaUtils.
no setter
$value EsquemaUtils
Instancia de EsquemaUtils que está siendo envuelta.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) → $Value?
Método que permite acceder a las propiedades y métodos de la instancia envuelta desde el código interpretado.
$getRuntimeType(Runtime runtime) int
Devuelve el identificador de tipo en tiempo de ejecución, utilizado por dart_eval para manejar el tipo de la instancia.
$setProperty(Runtime runtime, String identifier, $Value value) → void
Método que lanza una excepción, ya que EsquemaUtils no tiene propiedades que puedan ser modificadas desde el código interpretado.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

$declaration → BridgeClassDef
final
$type → BridgeTypeRef
final

Static Methods

$new(Runtime runtime, $Value? target, List<$Value?> args) → $Value?
Función que crea una nueva instancia de $EsquemaUtils al ser llamada desde el código interpretado.

Constants

clase → const String
package → const String