SocketBloc class
- Available extensions
Constructors
- SocketBloc({required ApiRest apiRest, bool debugMode = false, required ShpDynamicCrud shpDynamicCrud, required Uuid uuid, required FlutterSocketProvider socketDataProvider, required UtilsDataApiRest utilsDataApiRest, required String endpointSocket})
Properties
- apiRest → ApiRest
-
final
- debugMode → bool
-
final
- duracionTemporizador → Duration
-
final
- endpointSocket → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shpDynamicCrud → ShpDynamicCrud
-
final
- socketDataProvider → FlutterSocketProvider
-
final
- state → SocketState
-
The current state.
no setterinherited
-
stream
→ Stream<
SocketState> -
The current stream of states.
no setterinherited
-
timerColecciones
→ Map<
String, Timer> -
final
- utilsDataApiRest → UtilsDataApiRest
-
final
- uuid → Uuid
-
final
Methods
-
actualizaNotificacion(
Map< String, dynamic> payload) → Future<List< Map< >String, dynamic> > -
Available on SocketBloc, provided by the SocketFunc extension
-
add(
SocketEvent event) → void -
Notifies the
Blocof a neweventwhich triggers all correspondingEventHandlerinstances.inherited -
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
close(
) → Future< void> -
Closes the
eventandstateStreams. This method should be called when aBlocis no longer needed. Oncecloseis called,eventsthat areadded will not be processed. In addition, ifcloseis called whileeventsare still being processed, theBlocwill finish processing the pendingevents.inherited -
determinaMensajesSinLeer(
List< Map< lstData) → intString, dynamic> > -
Available on SocketBloc, provided by the SocketFunc extension
-
emit(
SocketState state) → void -
emitis only for internal use and should never be called directly outside of tests. TheEmitterinstance provided to eachEventHandlershould be used instead.inherited -
finalizaEscuchaSocketDataProvider(
String idColeccion) → void -
iniciaEscuchaSocketDataProvider(
String coleccion) → void -
iniciaEscuchaSocketOpcionales(
{required String endpointSocket, required String idChannel}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on<
E extends Event> (EventHandler< E, SocketState> handler, {EventTransformer<E> ? transformer}) → void -
Register event handler for an event of type
E. There should only ever be one event handler per event typeE.inherited -
onChange(
Change< SocketState> change) → void -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onDone(
SocketEvent event, [Object? error, StackTrace? stackTrace]) → void -
Called whenever an
eventhandler for a specificBlochas completed. This may include anerrorandstackTraceif an uncaught exception occurred within the event handler.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
onEvent(
SocketEvent event) → void -
Called whenever an
eventisadded to theBloc. A great spot to add logging/analytics at the individualBloclevel.inherited -
onTransition(
Transition< SocketEvent, SocketState> transition) → void -
Called whenever a
transitionoccurs with the giventransition. Atransitionoccurs when a neweventis added and a new state isemittedfrom a correspondingEventHandler.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- blocOnFinalizaEscuchaSocket → const String
- blocOnIniciaEscuchaPilaAtomica → const String
- blocOnIniciaEscuchaSocket → const String
- blocOnIniciaEscuchaSocketOpcionales → const String
- blocOnInitSocketEvent → const String
- blocOnMarcaComoLeido → const String
- blocOnObtieneMensajeSocket → const String